@@ -18,12 +18,20 @@ def _setup_common(self):
     input_data, output_data, partials_data = jl.OpenMDAOCore.setup(self._jlcomp)
 
     for var in input_data:
+        if var.tags is not None:
+            tags = list(var.tags)
+        else:
+            tags = None
         self.add_input(var.name, shape=var.shape, val=var.val,
-                       units=var.units)
+                       units=var.units, tags=tags)
 
     for var in output_data:
+        if var.tags is not None:
+            tags = list(var.tags)
+        else:
+            tags = None
         self.add_output(var.name, shape=var.shape, val=var.val,
-                        units=var.units, lower=var.lower, upper=var.upper)
+                        units=var.units, lower=var.lower, upper=var.upper, tags=tags)
 
     for data in partials_data:
         self.declare_partials(data.of, data.wrt,
