@@ -59,6 +59,32 @@ function OpenMDAOCore.compute_partials!(self::ECompWithOption, inputs, partials)
     return nothing
 end
 
+struct ECompWithOptionAndTags <: OpenMDAOCore.AbstractExplicitComp
+    a::Float64
+    xtag::Vector{String}
+    ytag::Vector{String}
+end
+
+ECompWithOptionAndTags(a; xtag, ytag) = ECompWithOptionAndTags(a, xtag, ytag)
+
+function OpenMDAOCore.setup(self::ECompWithOptionAndTags)
+    input_data = [VarData("x"; tags=self.xtag)]
+    output_data = [VarData("y"; tags=self.ytag)]
+    partials_data = [PartialsData("y", "x")]
+
+    return input_data, output_data, partials_data
+end
+
+function OpenMDAOCore.compute!(self::ECompWithOptionAndTags, inputs, outputs)
+    outputs["y"][1] = 2*self.a*inputs["x"][1]^2 + 1
+    return nothing
+end
+
+function OpenMDAOCore.compute_partials!(self::ECompWithOptionAndTags, inputs, partials)
+    partials["y", "x"][1] = 4*self.a*inputs["x"][1]
+    return nothing
+end
+
 struct ECompWithLargeOption <: OpenMDAOCore.AbstractExplicitComp
     a::Vector{Float64}
 end
